package
Version:
v0.0.0-...-3d8e725
Opens a new window with list of versions in this module.
Published: Oct 24, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Short struct {
Short string `json:"short"`
}
type URL struct {
URL string `json:"url"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.